ActivationOptions for the class
The activation status of the object. This field includes activation status if valuable supports activation.
Resource used when the AddMessage endpoints are called.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Information to read/write to blobstore2.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
A sequence of media data references representing composite data. Introduced to support Bigstore composite objects. For details, visit http://go/bigstore-composites.
Detailed Content-Type information from Scotty. The Content-Type of the media will typically be filled in by the header or Scotty’s best_guess, but this extended information provides the backend with more information so that it can make a better decision if needed. This is only used on media upload requests from Scotty.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Device context associated with the object.
Backend response for a Diff get checksums response. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol.
Backend response for a Diff download response. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol.
A Diff upload request. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol.
Backend response for a Diff upload request. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol.
Backend response for a Diff get version response. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol.
Information about how a class may be discovered and instantiated from within the Android Pay app. This is done by searching for a loyalty or gift card program and scanning or manually entering.
Information about the merchant hosted signin flow for a program.
Information about the merchant hosted signup flow for a program.
Parameters specific to media downloads.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Adds a message to the event ticket class referenced by the given class ID.
Returns the event ticket class with the given class ID.
Inserts an event ticket class with the given ID and properties.
Returns a list of all event ticket classes for a given issuer ID.
A builder providing access to all methods supported on
eventticketclas resources.
It is not used directly, but through the
Walletobjects hub.
Updates the event ticket class referenced by the given class ID. This method supports patch semantics.
Updates the event ticket class referenced by the given class ID.
Adds a message to the event ticket object referenced by the given object ID.
Returns the event ticket object with the given object ID.
Inserts an event ticket object with the given ID and properties.
Returns a list of all event ticket objects for a given issuer ID.
A builder providing access to all methods supported on
eventticketobject resources.
It is not used directly, but through the
Walletobjects hub.
Modifies linked offer objects for the event ticket object with the given ID.
Updates the event ticket object referenced by the given object ID. This method supports patch semantics.
Updates the event ticket object referenced by the given object ID.
Indicates that the issuer would like Google Wallet to send expiry notifications 2 days prior to the card expiration.
Reference definition to use with field overrides.
Custom field selector to use with field overrides.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Adds a message to the flight class referenced by the given class ID.
Returns the flight class with the given class ID.
Inserts an flight class with the given ID and properties.
Returns a list of all flight classes for a given issuer ID.
A builder providing access to all methods supported on
flightclas resources.
It is not used directly, but through the
Walletobjects hub.
Updates the flight class referenced by the given class ID. This method supports patch semantics.
Updates the flight class referenced by the given class ID.
Adds a message to the flight object referenced by the given object ID.
Returns the flight object with the given object ID.
Inserts an flight object with the given ID and properties.
Returns a list of all flight objects for a given issuer ID.
A builder providing access to all methods supported on
flightobject resources.
It is not used directly, but through the
Walletobjects hub.
Updates the flight object referenced by the given object ID. This method supports patch semantics.
Updates the flight object referenced by the given object ID.
There is no detailed description.
Generic Class
Response to adding a new issuer message to the class. This contains the entire updated GenericClass.
List response which contains the list of all generic classes for a given issuer ID.
Generic Object Next ID: 121
Response to adding a new issuer message to the object. This contains the entire updated GenericObject.
List response which contains the list of all generic objects for a given issuer ID.
Adds a message to the generic class referenced by the given class ID.
Returns the generic class with the given class ID.
Inserts a generic class with the given ID and properties.
Returns a list of all generic classes for a given issuer ID.
A builder providing access to all methods supported on
genericclas resources.
It is not used directly, but through the
Walletobjects hub.
Updates the generic class referenced by the given class ID. This method supports patch semantics.
Updates the Generic class referenced by the given class ID.
Adds a message to the generic object referenced by the given object ID.
Returns the generic object with the given object ID.
Inserts a generic object with the given ID and properties.
Returns a list of all generic objects for a given issuer ID.
A builder providing access to all methods supported on
genericobject resources.
It is not used directly, but through the
Walletobjects hub.
Updates the generic object referenced by the given object ID. This method supports patch semantics.
Updates the generic object referenced by the given object ID.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Adds a message to the gift card class referenced by the given class ID.
Returns the gift card class with the given class ID.
Inserts an gift card class with the given ID and properties.
Returns a list of all gift card classes for a given issuer ID.
A builder providing access to all methods supported on
giftcardclas resources.
It is not used directly, but through the
Walletobjects hub.
Updates the gift card class referenced by the given class ID. This method supports patch semantics.
Updates the gift card class referenced by the given class ID.
Adds a message to the gift card object referenced by the given object ID.
Returns the gift card object with the given object ID.
Inserts an gift card object with the given ID and properties.
Returns a list of all gift card objects for a given issuer ID.
A builder providing access to all methods supported on
giftcardobject resources.
It is not used directly, but through the
Walletobjects hub.
Updates the gift card object referenced by the given object ID. This method supports patch semantics.
Updates the gift card object referenced by the given object ID.
There is no detailed description.
Wrapping type for Google hosted images. Next ID: 7
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Returns the issuer with the given issuer ID.
Inserts an issuer with the given ID and properties.
Returns a list of all issuers shared to the caller.
There is no detailed description.
A builder providing access to all methods supported on
issuer resources.
It is not used directly, but through the
Walletobjects hub.
Updates the issuer referenced by the given issuer ID. This method supports patch semantics.
There is no detailed description.
Updates the issuer referenced by the given issuer ID.
Inserts the resources in the JWT.
There is no detailed description.
A builder providing access to all methods supported on
jwt resources.
It is not used directly, but through the
Walletobjects hub.
There is no detailed description.
A pair of text strings to be displayed in the details view. Note we no longer display LabelValue/LabelValueRow as a table, instead a list of items.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Adds a message to the loyalty class referenced by the given class ID.
Returns the loyalty class with the given class ID.
Inserts an loyalty class with the given ID and properties.
Returns a list of all loyalty classes for a given issuer ID.
A builder providing access to all methods supported on
loyaltyclas resources.
It is not used directly, but through the
Walletobjects hub.
Updates the loyalty class referenced by the given class ID. This method supports patch semantics.
Updates the loyalty class referenced by the given class ID.
Adds a message to the loyalty object referenced by the given object ID.
Returns the loyalty object with the given object ID.
Inserts an loyalty object with the given ID and properties.
Returns a list of all loyalty objects for a given issuer ID.
A builder providing access to all methods supported on
loyaltyobject resources.
It is not used directly, but through the
Walletobjects hub.
Modifies linked offer objects for the loyalty object with the given ID.
Updates the loyalty object referenced by the given object ID. This method supports patch semantics.
Updates the loyalty object referenced by the given object ID.
A reference to data stored on the filesystem, on GFS or in blobstore.
Downloads rotating barcode values for the transit object referenced by the given object ID.
A builder providing access to all methods supported on
media resources.
It is not used directly, but through the
Walletobjects hub.
Extra information added to operations that support Scotty media requests.
Uploads rotating barcode values for the transit object referenced by the given object ID. Note the max upload size is specified in google3/production/config/cdd/apps-upload/customers/payments-consumer-passes/config.gcl and enforced by Scotty.
A message that will be displayed with a Valuable
There is no detailed description.
There is no detailed description.
There is no detailed description.
Indicates if the object needs to have notification enabled. We support only one of ExpiryNotification/UpcomingNotification. expiryNotification takes precedence over upcomingNotification. In other words if expiryNotification is set, we ignore the upcomingNotification field.
This is a copy of the tech.blob.ObjectId proto, which could not be used directly here due to transitive closure issues with JavaScript support; see http://b/8801763.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Adds a message to the offer class referenced by the given class ID.
Returns the offer class with the given class ID.
Inserts an offer class with the given ID and properties.
Returns a list of all offer classes for a given issuer ID.
A builder providing access to all methods supported on
offerclas resources.
It is not used directly, but through the
Walletobjects hub.
Updates the offer class referenced by the given class ID. This method supports patch semantics.
Updates the offer class referenced by the given class ID.
Adds a message to the offer object referenced by the given object ID.
Returns the offer object with the given object ID.
Inserts an offer object with the given ID and properties.
Returns a list of all offer objects for a given issuer ID.
A builder providing access to all methods supported on
offerobject resources.
It is not used directly, but through the
Walletobjects hub.
Updates the offer object referenced by the given object ID. This method supports patch semantics.
Updates the offer object referenced by the given object ID.
There is no detailed description.
Container for any constraints that may be placed on passes.
There is no detailed description.
Returns the permissions for the given issuer id.
A builder providing access to all methods supported on
permission resources.
It is not used directly, but through the
Walletobjects hub.
Updates the permissions for the given issuer.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Configuration for the time-based OTP substitutions. See https://tools.ietf.org/html/rfc6238
Configuration for the key and value length. See https://www.rfc-editor.org/rfc/rfc4226#section-5.3
A payload containing many barcode values and start date/time.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Inserts the smart tap.
A builder providing access to all methods supported on
smarttap resources.
It is not used directly, but through the
Walletobjects hub.
There is no detailed description.
Data for Text module. All fields are optional. Header will be displayed if available, different types of bodies will be concatenated if they are defined.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
There is no detailed description.
Request to upload rotating barcode values.
Response for uploading rotating barcode values.
Adds a message to the transit class referenced by the given class ID.
Returns the transit class with the given class ID.
Inserts a transit class with the given ID and properties.
Returns a list of all transit classes for a given issuer ID.
A builder providing access to all methods supported on
transitclas resources.
It is not used directly, but through the
Walletobjects hub.
Updates the transit class referenced by the given class ID. This method supports patch semantics.
Updates the transit class referenced by the given class ID.
Adds a message to the transit object referenced by the given object ID.
Returns the transit object with the given object ID.
Inserts an transit object with the given ID and properties.
Returns a list of all transit objects for a given issuer ID.
A builder providing access to all methods supported on
transitobject resources.
It is not used directly, but through the
Walletobjects hub.
Updates the transit object referenced by the given object ID. This method supports patch semantics.
Updates the transit object referenced by the given object ID.
There is no detailed description.
Indicates that the issuer would like Google Wallet to send an upcoming card validity notification 1 day before card becomes valid/usable.
There is no detailed description.
Central instance to access all Walletobjects related resource activities