Struct google_walletobjects1::api::AppLinkDataAppLinkInfo
source · pub struct AppLinkDataAppLinkInfo {
pub app_logo_image: Option<Image>,
pub app_target: Option<AppLinkDataAppLinkInfoAppTarget>,
pub description: Option<LocalizedString>,
pub title: Option<LocalizedString>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
app_logo_image: Option<Image>Optional image to be displayed in the App Link Module
app_target: Option<AppLinkDataAppLinkInfoAppTarget>Url to follow when opening the App Link Module on clients. It will be used by partners to open their webpage or deeplink into their app.
description: Option<LocalizedString>String to be displayed in the description of the App Link Module Required
title: Option<LocalizedString>String to be displayed in the title of the App Link Module Required