pub struct Blobstore2Info {
pub blob_generation: Option<i64>,
pub blob_id: Option<String>,
pub download_external_read_token: Option<Vec<u8>>,
pub download_read_handle: Option<Vec<u8>>,
pub read_token: Option<String>,
pub upload_metadata_container: Option<Vec<u8>>,
}Expand description
Information to read/write to blobstore2.
This type is not used in any activity, and only used as part of another schema.
Fields
blob_generation: Option<i64>The blob generation id.
blob_id: Option<String>The blob id, e.g., /blobstore/prod/playground/scotty
download_external_read_token: Option<Vec<u8>>A serialized External Read Token passed from Bigstore -> Scotty for a GCS download. This field must never be consumed outside of Bigstore, and is not applicable to non-GCS media uploads.
download_read_handle: Option<Vec<u8>>Read handle passed from Bigstore -> Scotty for a GCS download. This is a signed, serialized blobstore2.ReadHandle proto which must never be set outside of Bigstore, and is not applicable to non-GCS media downloads.
read_token: Option<String>The blob read token. Needed to read blobs that have not been replicated. Might not be available until the final call.
upload_metadata_container: Option<Vec<u8>>Metadata passed from Blobstore -> Scotty for a new GCS upload. This is a signed, serialized blobstore2.BlobMetadataContainer proto which must never be consumed outside of Bigstore, and is not applicable to non-GCS media uploads.