pub struct ContentTypeInfo {
pub best_guess: Option<String>,
pub from_bytes: Option<String>,
pub from_file_name: Option<String>,
pub from_header: Option<String>,
pub from_url_path: Option<String>,
}Expand description
Detailed Content-Type information from Scotty. The Content-Type of the media will typically be filled in by the header or Scotty’s best_guess, but this extended information provides the backend with more information so that it can make a better decision if needed. This is only used on media upload requests from Scotty.
This type is not used in any activity, and only used as part of another schema.
Fields
best_guess: Option<String>Scotty’s best guess of what the content type of the file is.
from_bytes: Option<String>The content type of the file derived by looking at specific bytes (i.e. “magic bytes”) of the actual file.
from_file_name: Option<String>The content type of the file derived from the file extension of the original file name used by the client.
from_header: Option<String>The content type of the file as specified in the request headers, multipart headers, or RUPIO start request.
from_url_path: Option<String>The content type of the file derived from the file extension of the URL path. The URL path is assumed to represent a file name (which is typically only true for agents that are providing a REST API).