pub struct EventSeat {
pub gate: Option<LocalizedString>,
pub kind: Option<String>,
pub row: Option<LocalizedString>,
pub seat: Option<LocalizedString>,
pub section: Option<LocalizedString>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
gate: Option<LocalizedString>The gate the ticket holder should enter to get to their seat, such as “A” or “West”. This field is localizable so you may translate words or use different alphabets for the characters in an identifier.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string "walletobjects#eventSeat".
row: Option<LocalizedString>The row of the seat, such as “1”, E“, “BB”, or “A5”. This field is localizable so you may translate words or use different alphabets for the characters in an identifier.
seat: Option<LocalizedString>The seat number, such as “1”, “2”, “3”, or any other seat identifier. This field is localizable so you may translate words or use different alphabets for the characters in an identifier.
section: Option<LocalizedString>The section of the seat, such as “121”. This field is localizable so you may translate words or use different alphabets for the characters in an identifier.