pub struct FlightCarrier {
pub airline_alliance_logo: Option<Image>,
pub airline_logo: Option<Image>,
pub airline_name: Option<LocalizedString>,
pub carrier_iata_code: Option<String>,
pub carrier_icao_code: Option<String>,
pub kind: Option<String>,
pub wide_airline_logo: Option<Image>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
airline_alliance_logo: Option<Image>A logo for the airline alliance, displayed below the QR code that the passenger scans to board.
airline_logo: Option<Image>A logo for the airline described by carrierIataCode and localizedAirlineName. This logo will be rendered at the top of the detailed card view.
airline_name: Option<LocalizedString>A localized name of the airline specified by carrierIataCode. If unset, issuer_name or localized_issuer_name from FlightClass will be used for display purposes. eg: “Swiss Air” for “LX”
carrier_iata_code: Option<String>Two character IATA airline code of the marketing carrier (as opposed to operating carrier). Exactly one of this or carrierIcaoCode needs to be provided for carrier and operatingCarrier. eg: “LX” for Swiss Air
carrier_icao_code: Option<String>Three character ICAO airline code of the marketing carrier (as opposed to operating carrier). Exactly one of this or carrierIataCode needs to be provided for carrier and operatingCarrier. eg: “EZY” for Easy Jet
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string "walletobjects#flightCarrier".
wide_airline_logo: Option<Image>The wide logo of the airline. When provided, this will be used in place of the airline logo in the top left of the card view.