Struct google_walletobjects1::api::IssuerMethods
source · pub struct IssuerMethods<'a, S>where
S: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on issuer resources.
It is not used directly, but through the Walletobjects hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_walletobjects1 as walletobjects1;
use std::default::Default;
use walletobjects1::{Walletobjects, oauth2, hyper, hyper_rustls, chrono, FieldMask};
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = Walletobjects::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)`, `insert(...)`, `list(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.issuer();Implementations
sourceimpl<'a, S> IssuerMethods<'a, S>
impl<'a, S> IssuerMethods<'a, S>
sourcepub fn get(&self, resource_id: i64) -> IssuerGetCall<'a, S>
pub fn get(&self, resource_id: i64) -> IssuerGetCall<'a, S>
Create a builder to help you perform the following task:
Returns the issuer with the given issuer ID.
Arguments
resourceId- The unique identifier for an issuer.
sourcepub fn insert(&self, request: Issuer) -> IssuerInsertCall<'a, S>
pub fn insert(&self, request: Issuer) -> IssuerInsertCall<'a, S>
Create a builder to help you perform the following task:
Inserts an issuer with the given ID and properties.
Arguments
request- No description provided.
sourcepub fn list(&self) -> IssuerListCall<'a, S>
pub fn list(&self) -> IssuerListCall<'a, S>
Create a builder to help you perform the following task:
Returns a list of all issuers shared to the caller.
sourcepub fn patch(&self, request: Issuer, resource_id: i64) -> IssuerPatchCall<'a, S>
pub fn patch(&self, request: Issuer, resource_id: i64) -> IssuerPatchCall<'a, S>
Create a builder to help you perform the following task:
Updates the issuer referenced by the given issuer ID. This method supports patch semantics.
Arguments
request- No description provided.resourceId- The unique identifier for an issuer.