Struct google_walletobjects1::api::JwtMethods
source · pub struct JwtMethods<'a, S>where
S: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on jwt resources.
It is not used directly, but through the Walletobjects hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_walletobjects1 as walletobjects1;
use std::default::Default;
use walletobjects1::{Walletobjects, oauth2, hyper, hyper_rustls, chrono, FieldMask};
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = Walletobjects::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `insert(...)`
// to build up your call.
let rb = hub.jwt();Implementations
sourceimpl<'a, S> JwtMethods<'a, S>
impl<'a, S> JwtMethods<'a, S>
sourcepub fn insert(&self, request: JwtResource) -> JwtInsertCall<'a, S>
pub fn insert(&self, request: JwtResource) -> JwtInsertCall<'a, S>
Create a builder to help you perform the following task:
Inserts the resources in the JWT.
Arguments
request- No description provided.