Struct google_walletobjects1::api::LoyaltyObject
source · pub struct LoyaltyObject {Show 28 fields
pub account_id: Option<String>,
pub account_name: Option<String>,
pub app_link_data: Option<AppLinkData>,
pub barcode: Option<Barcode>,
pub class_id: Option<String>,
pub class_reference: Option<LoyaltyClass>,
pub disable_expiration_notification: Option<bool>,
pub grouping_info: Option<GroupingInfo>,
pub has_linked_device: Option<bool>,
pub has_users: Option<bool>,
pub hero_image: Option<Image>,
pub id: Option<String>,
pub image_modules_data: Option<Vec<ImageModuleData>>,
pub info_module_data: Option<InfoModuleData>,
pub kind: Option<String>,
pub linked_offer_ids: Option<Vec<String>>,
pub links_module_data: Option<LinksModuleData>,
pub locations: Option<Vec<LatLongPoint>>,
pub loyalty_points: Option<LoyaltyPoints>,
pub messages: Option<Vec<Message>>,
pub pass_constraints: Option<PassConstraints>,
pub rotating_barcode: Option<RotatingBarcode>,
pub secondary_loyalty_points: Option<LoyaltyPoints>,
pub smart_tap_redemption_value: Option<String>,
pub state: Option<String>,
pub text_modules_data: Option<Vec<TextModuleData>>,
pub valid_time_interval: Option<TimeInterval>,
pub version: Option<i64>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get loyaltyobject (response)
- insert loyaltyobject (request|response)
- modifylinkedofferobjects loyaltyobject (response)
- patch loyaltyobject (request|response)
- update loyaltyobject (request|response)
Fields
account_id: Option<String>The loyalty account identifier. Recommended maximum length is 20 characters.
account_name: Option<String>The loyalty account holder name, such as “John Smith.” Recommended maximum length is 20 characters to ensure full string is displayed on smaller screens.
app_link_data: Option<AppLinkData>Optional information about the partner app link.
barcode: Option<Barcode>The barcode type and value.
class_id: Option<String>Required. The class associated with this object. The class must be of the same type as this object, must already exist, and must be approved. Class IDs should follow the format issuer ID.identifier where the former is issued by Google and latter is chosen by you.
class_reference: Option<LoyaltyClass>A copy of the inherited fields of the parent class. These fields are retrieved during a GET.
disable_expiration_notification: Option<bool>Indicates if notifications should explicitly be suppressed. If this field is set to true, regardless of the messages field, expiration notifications to the user will be suppressed. By default, this field is set to false. Currently, this can only be set for offers.
grouping_info: Option<GroupingInfo>Information that controls how passes are grouped together.
has_linked_device: Option<bool>Whether this object is currently linked to a single device. This field is set by the platform when a user saves the object, linking it to their device. Intended for use by select partners. Contact support for additional information.
has_users: Option<bool>Indicates if the object has users. This field is set by the platform.
hero_image: Option<Image>Optional banner image displayed on the front of the card. If none is present, hero image of the class, if present, will be displayed. If hero image of the class is also not present, nothing will be displayed.
id: Option<String>Required. The unique identifier for an object. This ID must be unique across all objects from an issuer. This value should follow the format issuer ID.identifier where the former is issued by Google and latter is chosen by you. The unique identifier should only include alphanumeric characters, ‘.’, ‘_’, or ‘-’.
image_modules_data: Option<Vec<ImageModuleData>>Image module data. The maximum number of these fields displayed is 1 from object level and 1 for class object level.
info_module_data: Option<InfoModuleData>Deprecated. Use textModulesData instead.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string "walletobjects#loyaltyObject".
linked_offer_ids: Option<Vec<String>>A list of offer objects linked to this loyalty card. The offer objects must already exist. Offer object IDs should follow the format issuer ID. identifier where the former is issued by Google and latter is chosen by you.
links_module_data: Option<LinksModuleData>Links module data. If links module data is also defined on the class, both will be displayed.
locations: Option<Vec<LatLongPoint>>Note: This field is currently not supported to trigger geo notifications.
loyalty_points: Option<LoyaltyPoints>The loyalty reward points label, balance, and type.
messages: Option<Vec<Message>>An array of messages displayed in the app. All users of this object will receive its associated messages. The maximum number of these fields is 10.
pass_constraints: Option<PassConstraints>Pass constraints for the object. Includes limiting NFC and screenshot behaviors.
rotating_barcode: Option<RotatingBarcode>The rotating barcode type and value.
secondary_loyalty_points: Option<LoyaltyPoints>The secondary loyalty reward points label, balance, and type. Shown in addition to the primary loyalty points.
smart_tap_redemption_value: Option<String>The value that will be transmitted to a Smart Tap certified terminal over NFC for this object. The class level fields enableSmartTap and redemptionIssuers must also be set up correctly in order for the pass to support Smart Tap. Only ASCII characters are supported. If this value is not set but the class level fields enableSmartTap and redemptionIssuers are set up correctly, the barcode.value or the accountId fields are used as fallback if present.
state: Option<String>Required. The state of the object. This field is used to determine how an object is displayed in the app. For example, an inactive object is moved to the “Expired passes” section.
text_modules_data: Option<Vec<TextModuleData>>Text module data. If text module data is also defined on the class, both will be displayed. The maximum number of these fields displayed is 10 from the object and 10 from the class.
valid_time_interval: Option<TimeInterval>The time period this object will be active and object can be used. An object’s state will be changed to expired when this time period has passed.
version: Option<i64>Deprecated