Struct google_walletobjects1::api::PermissionMethods
source · pub struct PermissionMethods<'a, S>where
S: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on permission resources.
It is not used directly, but through the Walletobjects hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_walletobjects1 as walletobjects1;
use std::default::Default;
use walletobjects1::{Walletobjects, oauth2, hyper, hyper_rustls, chrono, FieldMask};
let secret: oauth2::ApplicationSecret = Default::default();
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = Walletobjects::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)` and `update(...)`
// to build up your call.
let rb = hub.permissions();Implementations
sourceimpl<'a, S> PermissionMethods<'a, S>
impl<'a, S> PermissionMethods<'a, S>
sourcepub fn get(&self, resource_id: i64) -> PermissionGetCall<'a, S>
pub fn get(&self, resource_id: i64) -> PermissionGetCall<'a, S>
Create a builder to help you perform the following task:
Returns the permissions for the given issuer id.
Arguments
resourceId- The unique identifier for an issuer. This ID must be unique across all issuers.
sourcepub fn update(
&self,
request: Permissions,
resource_id: i64
) -> PermissionUpdateCall<'a, S>
pub fn update( &self, request: Permissions, resource_id: i64 ) -> PermissionUpdateCall<'a, S>
Create a builder to help you perform the following task:
Updates the permissions for the given issuer.
Arguments
request- No description provided.resourceId- The unique identifier for an issuer. This ID must be unique across all issuers.