Struct google_walletobjects1::api::Walletobjects
source · pub struct Walletobjects<S> {
pub client: Client<S, Body>,
pub auth: Box<dyn GetToken>,
/* private fields */
}Expand description
Central instance to access all Walletobjects related resource activities
Examples
Instantiate a new hub
extern crate hyper;
extern crate hyper_rustls;
extern crate google_walletobjects1 as walletobjects1;
use walletobjects1::api::AddMessageRequest;
use walletobjects1::{Result, Error};
use std::default::Default;
use walletobjects1::{Walletobjects, oauth2, hyper, hyper_rustls, chrono, FieldMask};
// Get an ApplicationSecret instance by some means. It contains the `client_id` and
// `client_secret`, among other things.
let secret: oauth2::ApplicationSecret = Default::default();
// Instantiate the authenticator. It will choose a suitable authentication flow for you,
// unless you replace `None` with the desired Flow.
// Provide your own `AuthenticatorDelegate` to adjust the way it operates and get feedback about
// what's going on. You probably want to bring in your own `TokenStorage` to persist tokens and
// retrieve them from storage.
let auth = oauth2::InstalledFlowAuthenticator::builder(
secret,
oauth2::InstalledFlowReturnMethod::HTTPRedirect,
).build().await.unwrap();
let mut hub = Walletobjects::new(hyper::Client::builder().build(hyper_rustls::HttpsConnectorBuilder::new().with_native_roots().https_or_http().enable_http1().build()), auth);
// As the method needs a request, you would usually fill it with the desired information
// into the respective structure. Some of the parts shown here might not be applicable !
// Values shown here are possibly random and not representative !
let mut req = AddMessageRequest::default();
// You can configure optional parameters by calling the respective setters at will, and
// execute the final call using `doit()`.
// Values shown here are possibly random and not representative !
let result = hub.eventticketclass().addmessage(req, "resourceId")
.doit().await;
match result {
Err(e) => match e {
// The Error enum provides details about what exactly happened.
// You can also just use its `Debug`, `Display` or `Error` traits
Error::HttpError(_)
|Error::Io(_)
|Error::MissingAPIKey
|Error::MissingToken(_)
|Error::Cancelled
|Error::UploadSizeLimitExceeded(_, _)
|Error::Failure(_)
|Error::BadRequest(_)
|Error::FieldClash(_)
|Error::JsonDecodeError(_, _) => println!("{}", e),
},
Ok(res) => println!("Success: {:?}", res),
}Fields
client: Client<S, Body>auth: Box<dyn GetToken>Implementations
sourceimpl<'a, S> Walletobjects<S>
impl<'a, S> Walletobjects<S>
pub fn new<A: 'static + GetToken>( client: Client<S, Body>, auth: A ) -> Walletobjects<S>
pub fn eventticketclass(&'a self) -> EventticketclasMethods<'a, S>
pub fn eventticketobject(&'a self) -> EventticketobjectMethods<'a, S>
pub fn flightclass(&'a self) -> FlightclasMethods<'a, S>
pub fn flightobject(&'a self) -> FlightobjectMethods<'a, S>
pub fn genericclass(&'a self) -> GenericclasMethods<'a, S>
pub fn genericobject(&'a self) -> GenericobjectMethods<'a, S>
pub fn giftcardclass(&'a self) -> GiftcardclasMethods<'a, S>
pub fn giftcardobject(&'a self) -> GiftcardobjectMethods<'a, S>
pub fn issuer(&'a self) -> IssuerMethods<'a, S>
pub fn jwt(&'a self) -> JwtMethods<'a, S>
pub fn loyaltyclass(&'a self) -> LoyaltyclasMethods<'a, S>
pub fn loyaltyobject(&'a self) -> LoyaltyobjectMethods<'a, S>
pub fn media(&'a self) -> MediaMethods<'a, S>
pub fn offerclass(&'a self) -> OfferclasMethods<'a, S>
pub fn offerobject(&'a self) -> OfferobjectMethods<'a, S>
pub fn permissions(&'a self) -> PermissionMethods<'a, S>
pub fn smarttap(&'a self) -> SmarttapMethods<'a, S>
pub fn transitclass(&'a self) -> TransitclasMethods<'a, S>
pub fn transitobject(&'a self) -> TransitobjectMethods<'a, S>
sourcepub fn user_agent(&mut self, agent_name: String) -> String
pub fn user_agent(&mut self, agent_name: String) -> String
Set the user-agent header field to use in all requests to the server.
It defaults to google-api-rust-client/5.0.4.
Returns the previously set user-agent.